KaiselFlowSnapshot class

An active modal flow: its nesting depth, type, result-type hint, and the flow's own sub-stack.

Constructors

KaiselFlowSnapshot({required int depth, required String type, String? resultType, required KaiselStackSnapshot stack})
Create a flow snapshot.
const

Properties

depth int
Nesting depth (0 = outermost flow).
final
hashCode int
The hash code for this object.
no setterinherited
resultType String?
The flow's result type, if recoverable (usually null — erased).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack KaiselStackSnapshot
The flow's own sub-router stack.
final
type String
The flow's defining route type name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serialise to the wire format.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited