KaiselGuardStep<R extends KaiselRoute> class

One guard's effect within a KaiselGuardRun.

Annotations
  • @immutable

Constructors

KaiselGuardStep({required String label, required List<R> input, required List<R> output, required bool changed})
Create a guard-step record.
const

Properties

changed bool
Whether this guard changed the stack.
final
hashCode int
The hash code for this object.
no setterinherited
input List<R>
The stack this guard received.
final
label String
Best-effort label. Guards are usually anonymous closures, so this is the pipeline index, e.g. #0.
final
output List<R>
The stack this guard produced.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited