KaiselGuardStepSnapshot class

One guard's effect within a pipeline run.

Constructors

KaiselGuardStepSnapshot({required String guard, required List<String> input, required List<String> output, required bool changed})
Create a guard-step snapshot.
const

Properties

changed bool
Whether this guard changed the stack.
final
guard String
Best-effort guard label (closures are anonymous; index-based).
final
hashCode int
The hash code for this object.
no setterinherited
input List<String>
The stack this guard received, as route labels.
final
output List<String>
The stack this guard produced, as route labels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serialise to the wire format.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited