KaiselModuleSnapshot class

A mounted module: its optional URL prefix, route-type hint, and stack.

Constructors

KaiselModuleSnapshot({String? prefix, required String routeType, required KaiselStackSnapshot stack})
Create a module snapshot.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
prefix String?
The module's URL mount prefix, if known.
final
routeType String
Best-effort route-type hint for the module.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack KaiselStackSnapshot
The module's internal stack.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serialise to the wire format.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited