version property
Schema version. Bumped only on breaking changes; additive changes keep the same version and consumers ignore unknown fields.
Implementation
final int version;
Schema version. Bumped only on breaking changes; additive changes keep the same version and consumers ignore unknown fields.
final int version;