KaiselProblemSnapshot class

A detected problem in the navigation state, surfaced in the Problems panel.

Constructors

KaiselProblemSnapshot({required String kind, required String router, required String detail})
Create a problem snapshot.
const

Properties

detail String
A human-readable description.
final
hashCode int
The hash code for this object.
no setterinherited
kind String
The problem kind, e.g. 'noOp'.
final
router String
Which router it occurred on, e.g. 'main', 'shell0.branch1', 'flow:0'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serialise to the wire format.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited