nestedState property
State of the currently-mounted nested router (shell or module),
if any. null when no nested router is on top, or when the
codec didn't bother to describe it.
Implementation
final KaiselNestedConfig? nestedState;
State of the currently-mounted nested router (shell or module),
if any. null when no nested router is on top, or when the
codec didn't bother to describe it.
final KaiselNestedConfig? nestedState;