KaiselBranchSnapshot class
One branch of a shell: its index, route-type hint, and stack.
Constructors
- KaiselBranchSnapshot({required int index, required String routeType, required KaiselStackSnapshot stack})
-
Create a branch snapshot.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
The branch index.
final
- routeType → String
-
Best-effort route-type hint for the branch.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stack → KaiselStackSnapshot
-
The branch's stack.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serialise to the wire format.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited