KaiselStackSnapshot class
A single router's stack: its depth, whether it can pop, and its entries.
Constructors
-
KaiselStackSnapshot({required int depth, required bool canPop, required List<
KaiselEntrySnapshot> entries}) -
Create a stack snapshot.
const
Properties
- canPop → bool
-
Whether a pop would remove a route.
final
- depth → int
-
Number of routes on the stack.
final
-
entries
→ List<
KaiselEntrySnapshot> -
The stack entries, bottom to top.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serialise to the wire format.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited